@@ -332,7 +332,7 @@
     </message>
     <message>
         <source>&amp;Clear recent keywords</source>
-        <translation>&amp;مسح كلمات البحث السابقة</translation>
+        <translation type="obsolete">&amp;مسح كلمات البحث السابقة</translation>
     </message>
     <message>
         <source>Clear the search history. Cannot be undone.</source>
@@ -490,6 +490,10 @@
         <source>Downloads complete</source>
         <translation>التحميل انتهى</translation>
     </message>
+    <message>
+        <source>&amp;Clear recent searches</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>MediaView</name>
@@ -519,7 +523,7 @@
     </message>
     <message>
         <source>You&apos;re watching &quot;%1&quot;</source>
-        <translation>انت تشاهد &quot;%1&quot;</translation>
+        <translation type="obsolete">انت تشاهد &quot;%1&quot;</translation>
     </message>
     <message>
         <source>This is just the demo version of %1.</source>
@@ -557,7 +561,7 @@
     </message>
     <message>
         <source>%1 of %2 (%3) ? %4</source>
-        <translation>%1 of %2 (%3) ? %4</translation>
+        <translation type="obsolete">%1 of %2 (%3) ? %4</translation>
     </message>
     <message>
         <source>Preparing</source>
@@ -591,6 +595,10 @@
         <source>Restart downloading</source>
         <translation>اعادة التحميل</translation>
     </message>
+    <message>
+        <source>%1 of %2 (%3) — %4</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>SearchLineEdit</name>
@@ -607,7 +615,7 @@
     </message>
     <message>
         <source>Enter a keyword to start watching videos.</source>
-        <translation>اختر كلمة بحث للبدء في مشاهدة المقاطع.</translation>
+        <translation type="obsolete">اختر كلمة بحث للبدء في مشاهدة المقاطع.</translation>
     </message>
     <message>
         <source>Watch</source>
@@ -625,6 +633,31 @@
         <source>Make yourself comfortable</source>
         <translation>اجعل نفسك مرتاحا</translation>
     </message>
+    <message>
+        <source>Get the full version</source>
+        <translation type="unfinished">احصل على النسخة الكاملة</translation>
+    </message>
+    <message>
+        <source>Enter</source>
+        <extracomment>&quot;Enter&quot;, as in &quot;type&quot;. The whole frase says: &quot;Enter a keyword to start watching videos&quot;</extracomment>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>a keyword</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>a channel</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>to start watching videos.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Recent channels</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>Video</name>
@@ -632,5 +665,9 @@
         <source>Network error: %1 for %2</source>
         <translation>خطأ شبكة:%1 الى %2</translation>
     </message>
+    <message>
+        <source>Cannot get video stream for %1</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 </TS>
