@@ -120,9 +120,10 @@
     <name>DownloadManager</name>
     <message numerus="yes">
         <source>%n Download(s)</source>
+        <translatorcomment> </translatorcomment>
         <translation>
+            <numerusform>%n Λήψη</numerusform>
             <numerusform>%n Λήψεις</numerusform>
-            <numerusform></numerusform>
         </translation>
     </message>
     <message>
@@ -497,7 +498,7 @@
     </message>
     <message>
         <source>&amp;Clear recent keywords</source>
-        <translation>&amp;Καθαρισμός πρόσφατων αναζητήσεων</translation>
+        <translation type="obsolete">&amp;Καθαρισμός πρόσφατων αναζητήσεων</translation>
     </message>
     <message>
         <source>Clear the search history. Cannot be undone.</source>
@@ -576,6 +577,10 @@
         <source>Downloads complete</source>
         <translation>Οι λήψεις ολοκληρώθηκαν</translation>
     </message>
+    <message>
+        <source>&amp;Clear recent searches</source>
+        <translation>&amp;Καθαρισμός πρόσφατων αναζητήσεων</translation>
+    </message>
 </context>
 <context>
     <name>MediaView</name>
@@ -593,7 +598,7 @@
     </message>
     <message>
         <source>You&apos;re watching &quot;%1&quot;</source>
-        <translation>Βλέπετε «%1»</translation>
+        <translation type="obsolete">Βλέπετε «%1»</translation>
     </message>
     <message>
         <source>You can now paste the YouTube link into another application</source>
@@ -642,9 +647,9 @@
         <translation>Προβολές %1</translation>
     </message>
     <message>
-        <source>%1 of %2 (%3) ? %4</source>
+        <source>%1 of %2 (%3) — %4</source>
         <translatorcomment>needed description of what this variables represent so it can be translated..</translatorcomment>
-        <translation type="unfinished"></translation>
+        <translation>%1 από %2 (%3) — %4</translation>
     </message>
     <message>
         <source>Preparing</source>
@@ -694,7 +699,7 @@
     </message>
     <message>
         <source>Enter a keyword to start watching videos.</source>
-        <translation>Εισάγετε μια λέξη-κλειδί για να αρχίσετε να βλέπετε βίντεο.</translation>
+        <translation type="obsolete">Εισάγετε μια λέξη-κλειδί για να αρχίσετε να βλέπετε βίντεο.</translation>
     </message>
     <message>
         <source>Watch</source>
@@ -712,6 +717,31 @@
         <source>Make yourself comfortable</source>
         <translation>Βολευτείτε</translation>
     </message>
+    <message>
+        <source>Get the full version</source>
+        <translation>Αποκτήστε την πλήρη έκδοση</translation>
+    </message>
+    <message>
+        <source>Enter</source>
+        <extracomment>&quot;Enter&quot;, as in &quot;type&quot;. The whole frase says: &quot;Enter a keyword to start watching videos&quot;</extracomment>
+        <translation>Πληκτρολογήστε</translation>
+    </message>
+    <message>
+        <source>a keyword</source>
+        <translation>μια λέξη-κλειδί</translation>
+    </message>
+    <message>
+        <source>a channel</source>
+        <translation>ένα κανάλι</translation>
+    </message>
+    <message>
+        <source>to start watching videos.</source>
+        <translation>για να αρχίσετε να βλέπετε βίντεο.</translation>
+    </message>
+    <message>
+        <source>Recent channels</source>
+        <translation>Πρόσφατα κανάλια</translation>
+    </message>
 </context>
 <context>
     <name>SettingsView</name>
@@ -746,5 +776,9 @@
         <source>Network error: %1 for %2</source>
         <translation>Σφάλμα δικτύου: %1 για %2</translation>
     </message>
+    <message>
+        <source>Cannot get video stream for %1</source>
+        <translation>Αδυναμία ανάκτησης ροής βίντεο για %1</translation>
+    </message>
 </context>
 </TS>
