@@ -491,7 +491,7 @@
     </message>
     <message>
         <source>&amp;Clear recent keywords</source>
-        <translation>Limpiar palabras &amp;clave recientes</translation>
+        <translation type="obsolete">Limpiar palabras &amp;clave recientes</translation>
     </message>
     <message>
         <source>Clear the search history. Cannot be undone.</source>
@@ -570,6 +570,10 @@
         <source>Downloads complete</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>&amp;Clear recent searches</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>MediaView</name>
@@ -587,7 +591,7 @@
     </message>
     <message>
         <source>You&apos;re watching &quot;%1&quot;</source>
-        <translation>Está viendo %1</translation>
+        <translation type="obsolete">Está viendo %1</translation>
     </message>
     <message>
         <source>You can now paste the YouTube link into another application</source>
@@ -635,10 +639,6 @@
         <source>%1 views</source>
         <translation>%1 visualizaciones</translation>
     </message>
-    <message>
-        <source>%1 of %2 (%3) ? %4</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <source>Preparing</source>
         <translation type="unfinished"></translation>
@@ -671,6 +671,10 @@
         <source>Restart downloading</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>%1 of %2 (%3) — %4</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>SearchLineEdit</name>
@@ -687,7 +691,7 @@
     </message>
     <message>
         <source>Enter a keyword to start watching videos.</source>
-        <translation>Introduzca una palabra clave para empezar a ver videos.</translation>
+        <translation type="obsolete">Introduzca una palabra clave para empezar a ver videos.</translation>
     </message>
     <message>
         <source>Watch</source>
@@ -705,6 +709,31 @@
         <source>Make yourself comfortable</source>
         <translation>Sientase cómodo</translation>
     </message>
+    <message>
+        <source>Get the full version</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Enter</source>
+        <extracomment>&quot;Enter&quot;, as in &quot;type&quot;. The whole frase says: &quot;Enter a keyword to start watching videos&quot;</extracomment>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>a keyword</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>a channel</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>to start watching videos.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Recent channels</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>SettingsView</name>
@@ -723,5 +752,9 @@
         <source>Network error: %1 for %2</source>
         <translation>Error de red: %1 por %2</translation>
     </message>
+    <message>
+        <source>Cannot get video stream for %1</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 </TS>
