@@ -328,7 +328,7 @@
     </message>
     <message>
         <source>&amp;Clear recent keywords</source>
-        <translation>&amp;Poista viimeisimmät hakusanat</translation>
+        <translation type="obsolete">&amp;Poista viimeisimmät hakusanat</translation>
     </message>
     <message>
         <source>Clear the search history. Cannot be undone.</source>
@@ -486,6 +486,10 @@
         <source>Downloads complete</source>
         <translation>Lataukset ovat valmistuneet</translation>
     </message>
+    <message>
+        <source>&amp;Clear recent searches</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>MediaView</name>
@@ -515,7 +519,7 @@
     </message>
     <message>
         <source>You&apos;re watching &quot;%1&quot;</source>
-        <translation>Nyt pyörii &quot;%1&quot;</translation>
+        <translation type="obsolete">Nyt pyörii &quot;%1&quot;</translation>
     </message>
     <message>
         <source>This is just the demo version of %1.</source>
@@ -553,7 +557,7 @@
     </message>
     <message>
         <source>%1 of %2 (%3) ? %4</source>
-        <translation>%1  %2 (%3)sta ? %4</translation>
+        <translation type="obsolete">%1  %2 (%3)sta ? %4</translation>
     </message>
     <message>
         <source>Preparing</source>
@@ -587,6 +591,10 @@
         <source>Restart downloading</source>
         <translation>Käynnistä lataus uudelleen</translation>
     </message>
+    <message>
+        <source>%1 of %2 (%3) — %4</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>SearchLineEdit</name>
@@ -603,7 +611,7 @@
     </message>
     <message>
         <source>Enter a keyword to start watching videos.</source>
-        <translation>Anna hakusana aloittaaksesi videoiden katselu.</translation>
+        <translation type="obsolete">Anna hakusana aloittaaksesi videoiden katselu.</translation>
     </message>
     <message>
         <source>Watch</source>
@@ -621,6 +629,31 @@
         <source>Make yourself comfortable</source>
         <translation>Tee olosi kotoisaksi</translation>
     </message>
+    <message>
+        <source>Get the full version</source>
+        <translation type="unfinished">Hanki täysi versio</translation>
+    </message>
+    <message>
+        <source>Enter</source>
+        <extracomment>&quot;Enter&quot;, as in &quot;type&quot;. The whole frase says: &quot;Enter a keyword to start watching videos&quot;</extracomment>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>a keyword</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>a channel</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>to start watching videos.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Recent channels</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>Video</name>
@@ -628,5 +661,9 @@
         <source>Network error: %1 for %2</source>
         <translation>Verkkovirhe: &quot;%1&quot; &quot;%2&quot;lle</translation>
     </message>
+    <message>
+        <source>Cannot get video stream for %1</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 </TS>
