@@ -460,7 +460,7 @@
     </message>
     <message>
         <source>&amp;Clear recent keywords</source>
-        <translation>&amp;Cancella le ultime ricerche</translation>
+        <translation type="obsolete">&amp;Cancella le ultime ricerche</translation>
     </message>
     <message>
         <source>Clear the search history. Cannot be undone.</source>
@@ -538,6 +538,10 @@
         <source>Downloads complete</source>
         <translation>I download sono completi</translation>
     </message>
+    <message>
+        <source>&amp;Clear recent searches</source>
+        <translation>&amp;Cancella le ultime ricerche</translation>
+    </message>
 </context>
 <context>
     <name>MediaView</name>
@@ -555,7 +559,7 @@
     </message>
     <message>
         <source>You&apos;re watching &quot;%1&quot;</source>
-        <translation>Stai guardando &quot;%1&quot;</translation>
+        <translation type="obsolete">Stai guardando &quot;%1&quot;</translation>
     </message>
     <message>
         <source>You can now paste the YouTube link into another application</source>
@@ -604,8 +608,8 @@
         <translation>%1 visualizzazioni</translation>
     </message>
     <message>
-        <source>%1 of %2 (%3) ? %4</source>
-        <translation>%1 di %2 (%3) ? %4</translation>
+        <source>%1 of %2 (%3) — %4</source>
+        <translation>%1 di %2 (%3) — %4</translation>
     </message>
     <message>
         <source>Preparing</source>
@@ -655,7 +659,7 @@
     </message>
     <message>
         <source>Enter a keyword to start watching videos.</source>
-        <translation>Scrivi una parola chiave per iniziare a guardare i video.</translation>
+        <translation type="obsolete">Scrivi una parola chiave per iniziare a guardare i video.</translation>
     </message>
     <message>
         <source>Watch</source>
@@ -673,6 +677,31 @@
         <source>Make yourself comfortable</source>
         <translation>Mettiti comodo</translation>
     </message>
+    <message>
+        <source>Get the full version</source>
+        <translation>Compra la versione completa</translation>
+    </message>
+    <message>
+        <source>Enter</source>
+        <extracomment>&quot;Enter&quot;, as in &quot;type&quot;. The whole frase says: &quot;Enter a keyword to start watching videos&quot;</extracomment>
+        <translation>Scrivi</translation>
+    </message>
+    <message>
+        <source>a keyword</source>
+        <translation>una parola chiave</translation>
+    </message>
+    <message>
+        <source>a channel</source>
+        <translation>un canale</translation>
+    </message>
+    <message>
+        <source>to start watching videos.</source>
+        <translation>per iniziare a guardare i video.</translation>
+    </message>
+    <message>
+        <source>Recent channels</source>
+        <translation>Ultimi canali</translation>
+    </message>
 </context>
 <context>
     <name>SettingsView</name>
@@ -699,5 +728,9 @@
         <source>Network error: %1 for %2</source>
         <translation>Errore di rete: %1 per %2</translation>
     </message>
+    <message>
+        <source>Cannot get video stream for %1</source>
+        <translation>Impossibile ottenere il flusso video per %1</translation>
+    </message>
 </context>
 </TS>
