@@ -433,10 +433,6 @@
         <source>Remaining time: %1</source>
         <translation type="unfinished"></translation>
     </message>
-    <message>
-        <source>&amp;Clear recent keywords</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <source>Clear the search history. Cannot be undone.</source>
         <translation type="unfinished"></translation>
@@ -513,6 +509,10 @@
         <source>Downloads complete</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>&amp;Clear recent searches</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>MediaView</name>
@@ -530,7 +530,7 @@
     </message>
     <message>
         <source>You&apos;re watching &quot;%1&quot;</source>
-        <translation>&quot;%1&quot;を閲覧中</translation>
+        <translation type="obsolete">&quot;%1&quot;を閲覧中</translation>
     </message>
     <message>
         <source>You can now paste the YouTube link into another application</source>
@@ -578,10 +578,6 @@
         <source>%1 views</source>
         <translation>%1回 閲覧</translation>
     </message>
-    <message>
-        <source>%1 of %2 (%3) ? %4</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <source>Preparing</source>
         <translation type="unfinished"></translation>
@@ -614,6 +610,10 @@
         <source>Restart downloading</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>%1 of %2 (%3) — %4</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>SearchLineEdit</name>
@@ -630,7 +630,7 @@
     </message>
     <message>
         <source>Enter a keyword to start watching videos.</source>
-        <translation>探している動画のキーワードを入力。</translation>
+        <translation type="obsolete">探している動画のキーワードを入力。</translation>
     </message>
     <message>
         <source>Watch</source>
@@ -648,6 +648,31 @@
         <source>Make yourself comfortable</source>
         <translation>さあリラックスしましょう</translation>
     </message>
+    <message>
+        <source>Get the full version</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Enter</source>
+        <extracomment>&quot;Enter&quot;, as in &quot;type&quot;. The whole frase says: &quot;Enter a keyword to start watching videos&quot;</extracomment>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>a keyword</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>a channel</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>to start watching videos.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Recent channels</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>SettingsView</name>
@@ -666,5 +691,9 @@
         <source>Network error: %1 for %2</source>
         <translation>ネットワークエラー: %1 (%2へのアクセスにて)</translation>
     </message>
+    <message>
+        <source>Cannot get video stream for %1</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 </TS>
