@@ -328,7 +328,7 @@
     </message>
     <message>
         <source>&amp;Clear recent keywords</source>
-        <translation>&amp;Wis de recente zoekopdrachten</translation>
+        <translation type="obsolete">&amp;Wis de recente zoekopdrachten</translation>
     </message>
     <message>
         <source>Clear the search history. Cannot be undone.</source>
@@ -486,6 +486,10 @@
         <source>Downloads complete</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>&amp;Clear recent searches</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>MediaView</name>
@@ -515,7 +519,7 @@
     </message>
     <message>
         <source>You&apos;re watching &quot;%1&quot;</source>
-        <translation>U kijkt naar &quot;%1&quot;</translation>
+        <translation type="obsolete">U kijkt naar &quot;%1&quot;</translation>
     </message>
     <message>
         <source>This is just the demo version of %1.</source>
@@ -551,10 +555,6 @@
         <source>%1 views</source>
         <translation>%1 bekeken</translation>
     </message>
-    <message>
-        <source>%1 of %2 (%3) ? %4</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <source>Preparing</source>
         <translation type="unfinished"></translation>
@@ -587,6 +587,10 @@
         <source>Restart downloading</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>%1 of %2 (%3) — %4</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>SearchLineEdit</name>
@@ -603,7 +607,7 @@
     </message>
     <message>
         <source>Enter a keyword to start watching videos.</source>
-        <translation>Vul een zoekterm in om te beginnen met het bekijken van video&apos;s.</translation>
+        <translation type="obsolete">Vul een zoekterm in om te beginnen met het bekijken van video&apos;s.</translation>
     </message>
     <message>
         <source>Watch</source>
@@ -621,6 +625,31 @@
         <source>Make yourself comfortable</source>
         <translation>Ga er lekker voor zitten</translation>
     </message>
+    <message>
+        <source>Get the full version</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Enter</source>
+        <extracomment>&quot;Enter&quot;, as in &quot;type&quot;. The whole frase says: &quot;Enter a keyword to start watching videos&quot;</extracomment>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>a keyword</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>a channel</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>to start watching videos.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Recent channels</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>Video</name>
@@ -628,5 +657,9 @@
         <source>Network error: %1 for %2</source>
         <translation>Netwerk fout %1 voor %2</translation>
     </message>
+    <message>
+        <source>Cannot get video stream for %1</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 </TS>
