@@ -6,7 +6,7 @@
     <name>AboutView</name>
     <message>
         <source>There&apos;s life outside the browser!</source>
-        <translation>Não há vida fora do navegador!</translation>
+        <translation>Há vida fora do navegador!</translation>
     </message>
     <message>
         <source>Version %1</source>
@@ -14,7 +14,7 @@
     </message>
     <message>
         <source>This is a &quot;Technology Preview&quot; release, do not expect it to be perfect.</source>
-        <translation type="obsolete">Este é um lançamento &quot;Prévio da Tecnologia&quot;, não esperamos que ela seja perfeita.</translation>
+        <translation type="obsolete">Este é um lançamento &quot;Prévio da Tecnologia&quot;, não espere que esteja perfeito.</translation>
     </message>
     <message>
         <source>Report bugs and send in your ideas to %1</source>
@@ -22,11 +22,11 @@
     </message>
     <message>
         <source>%1 is Free Software but its development takes precious time.</source>
-        <translation>%1 é um Software livre, mas o seu desenvolvimento tem um tempo precioso.</translation>
+        <translation>%1 é um Software livre, mas seu desenvolvimento toma um tempo precioso.</translation>
     </message>
     <message>
         <source>Please &lt;a href=&apos;%1&apos;&gt;donate via PayPal&lt;/a&gt; to support the continued development of %2.</source>
-        <translation type="obsolete">Por favor, &lt;a href=&apos;%1&apos;&gt;doções via PayPal&lt;/a&gt; para apoiar o desenvolvimento contínuo de %2.</translation>
+        <translation type="obsolete">Por favor, &lt;a href=&apos;%1&apos;&gt;doe via PayPal&lt;/a&gt; para apoiar o desenvolvimento continuado de %2.</translation>
     </message>
     <message>
         <source>Icon designed by %1.</source>
@@ -58,15 +58,15 @@
     </message>
     <message>
         <source>HTTP proxy support contributed by %1.</source>
-        <translation>Suporte a HTTP proxy contribuído por %1.</translation>
+        <translation>Suporte a proxy HTTP contribuído por %1.</translation>
     </message>
     <message>
         <source>Windows version built by %1</source>
-        <translation type="obsolete">Vesão da janela construída por %1</translation>
+        <translation type="obsolete">Versão de janela construída por %1</translation>
     </message>
     <message>
         <source>Please &lt;a href=&apos;%1&apos;&gt;donate&lt;/a&gt; to support the continued development of %2.</source>
-        <translation>Por favor &lt;a href=&apos;%1&apos;&gt;doe&lt;/a&gt; para apoiar o desenvolvimento contínuo de %2.</translation>
+        <translation>Por favor &lt;a href=&apos;%1&apos;&gt;doe&lt;/a&gt; para apoiar o desenvolvimento continuado de %2.</translation>
     </message>
 </context>
 <context>
@@ -80,146 +80,146 @@
     <name>DownloadItem</name>
     <message>
         <source>bytes</source>
-        <translation type="unfinished"></translation>
+        <translation>bytes</translation>
     </message>
     <message>
         <source>KB</source>
-        <translation type="unfinished"></translation>
+        <translation>KB</translation>
     </message>
     <message>
         <source>MB</source>
-        <translation type="unfinished"></translation>
+        <translation>MB</translation>
     </message>
     <message>
         <source>bytes/sec</source>
-        <translation type="unfinished"></translation>
+        <translation>bytes/seg</translation>
     </message>
     <message>
         <source>KB/sec</source>
-        <translation type="unfinished"></translation>
+        <translation>KB/seg</translation>
     </message>
     <message>
         <source>MB/sec</source>
-        <translation type="unfinished"></translation>
+        <translation>MB/seg</translation>
     </message>
     <message>
         <source>seconds</source>
-        <translation type="unfinished"></translation>
+        <translation>segundos</translation>
     </message>
     <message>
         <source>minutes</source>
-        <translation type="unfinished"></translation>
+        <translation>minutos</translation>
     </message>
     <message>
         <source>%4 %5 remaining</source>
-        <translation type="unfinished"></translation>
+        <translation>%4 %5 restantes</translation>
     </message>
 </context>
 <context>
     <name>DownloadManager</name>
     <message numerus="yes">
         <source>%n Download(s)</source>
-        <translation type="unfinished">
-            <numerusform></numerusform>
-            <numerusform></numerusform>
+        <translation>
+            <numerusform>%n Download</numerusform>
+            <numerusform>%n Downloads</numerusform>
         </translation>
     </message>
     <message>
         <source>This is just the demo version of %1.</source>
-        <translation type="unfinished"></translation>
+        <translation>Esta é apenas a versão demonstração de %1.</translation>
     </message>
     <message>
         <source>It can only download videos shorter than %1 minutes so you can test the download functionality.</source>
-        <translation type="unfinished"></translation>
+        <translation>Só pode fazer download de vídeos menores que %1 minutos para que você possa testar a funcionalidade de download.</translation>
     </message>
     <message>
         <source>Continue</source>
-        <translation type="unfinished"></translation>
+        <translation>Continuar</translation>
     </message>
     <message>
         <source>Get the full version</source>
-        <translation type="unfinished"></translation>
+        <translation>Obter a versão completa</translation>
     </message>
 </context>
 <context>
     <name>DownloadSettings</name>
     <message>
         <source>Change location...</source>
-        <translation type="unfinished"></translation>
+        <translation>Alterar local...</translation>
     </message>
     <message>
         <source>Choose the download location</source>
-        <translation type="unfinished"></translation>
+        <translation>Escolha um local para o download</translation>
     </message>
     <message>
         <source>Download location changed.</source>
-        <translation type="unfinished"></translation>
+        <translation>Local de download alterado.</translation>
     </message>
     <message>
         <source>Current downloads will still go in the previous location.</source>
-        <translation type="unfinished"></translation>
+        <translation>Downloads atuais ainda irão para o local anterior.</translation>
     </message>
     <message>
         <source>Downloading to: %1</source>
-        <translation type="unfinished"></translation>
+        <translation>Baixando para: %1</translation>
     </message>
 </context>
 <context>
     <name>DownloadView</name>
     <message>
         <source>Downloads</source>
-        <translation type="unfinished"></translation>
+        <translation>Downloads</translation>
     </message>
 </context>
 <context>
     <name>GlobalShortcuts</name>
     <message>
         <source>Play</source>
-        <translation type="unfinished"></translation>
+        <translation>Reproduzir</translation>
     </message>
     <message>
         <source>Pause</source>
-        <translation type="unfinished"></translation>
+        <translation>Pausar</translation>
     </message>
     <message>
         <source>Play/Pause</source>
-        <translation type="unfinished"></translation>
+        <translation>Reproduzir/Pausar</translation>
     </message>
     <message>
         <source>Stop</source>
-        <translation type="unfinished"></translation>
+        <translation>Parar</translation>
     </message>
     <message>
         <source>Stop playing after current track</source>
-        <translation type="unfinished"></translation>
+        <translation>Parar reprodução após a faixa atual</translation>
     </message>
     <message>
         <source>Next track</source>
-        <translation type="unfinished"></translation>
+        <translation>Próxima faixa</translation>
     </message>
     <message>
         <source>Previous track</source>
-        <translation type="unfinished"></translation>
+        <translation>Faixa anterior</translation>
     </message>
     <message>
         <source>Increase volume</source>
-        <translation type="unfinished"></translation>
+        <translation>Aumentar volume</translation>
     </message>
     <message>
         <source>Decrease volume</source>
-        <translation type="unfinished"></translation>
+        <translation>Diminuir volume</translation>
     </message>
     <message>
         <source>Mute</source>
-        <translation type="unfinished"></translation>
+        <translation>Mudo</translation>
     </message>
     <message>
         <source>Seek forward</source>
-        <translation type="unfinished"></translation>
+        <translation>Avançar</translation>
     </message>
     <message>
         <source>Seek backward</source>
-        <translation type="unfinished"></translation>
+        <translation>Voltar</translation>
     </message>
 </context>
 <context>
@@ -230,7 +230,7 @@
     </message>
     <message>
         <source>Show %1 More</source>
-        <translation>Mostrar %1 a mais</translation>
+        <translation>Mostrar mais %1</translation>
     </message>
     <message>
         <source>No videos</source>
@@ -384,7 +384,7 @@
     </message>
     <message>
         <source>Please support the continued development of %1</source>
-        <translation>Por favor, apoie o desenvolvimento contínuo de %1</translation>
+        <translation>Por favor, apoie o desenvolvimento continuado de %1</translation>
     </message>
     <message>
         <source>&amp;About</source>
@@ -496,7 +496,7 @@
     </message>
     <message>
         <source>&amp;Clear recent keywords</source>
-        <translation>&amp;Apagar palavras-chave recentes</translation>
+        <translation type="obsolete">&amp;Apagar palavras-chave recentes</translation>
     </message>
     <message>
         <source>Clear the search history. Cannot be undone.</source>
@@ -540,39 +540,43 @@
     </message>
     <message>
         <source>&amp;Downloads</source>
-        <translation type="unfinished"></translation>
+        <translation>&amp;Downloads</translation>
     </message>
     <message>
         <source>Show details about video downloads</source>
-        <translation type="unfinished"></translation>
+        <translation>Mostrar detalhes sobre os downloads de vídeo</translation>
     </message>
     <message>
         <source>&amp;Download</source>
-        <translation type="unfinished"></translation>
+        <translation>&amp;Download</translation>
     </message>
     <message>
         <source>Download the current video</source>
-        <translation type="unfinished"></translation>
+        <translation>Baixar o vídeo atual</translation>
     </message>
     <message>
         <source>Do you want to exit %1 with a download in progress?</source>
-        <translation type="unfinished"></translation>
+        <translation>Você deseja sair de &quot;%1&quot; com uma transferência em curso?</translation>
     </message>
     <message>
         <source>If you close %1 now, this download will be cancelled.</source>
-        <translation type="unfinished"></translation>
+        <translation>Se você fechar %1 agora, este download será cancelado.</translation>
     </message>
     <message>
         <source>Close and cancel download</source>
-        <translation type="unfinished"></translation>
+        <translation>Fechar e cancelar download</translation>
     </message>
     <message>
         <source>Wait for download to finish</source>
-        <translation type="unfinished"></translation>
+        <translation>Aguardar o download terminar</translation>
     </message>
     <message>
         <source>Downloads complete</source>
-        <translation type="unfinished"></translation>
+        <translation>Downloads finalizados</translation>
+    </message>
+    <message>
+        <source>&amp;Clear recent searches</source>
+        <translation>&amp;Limpar pesquisas recentes</translation>
     </message>
 </context>
 <context>
@@ -591,7 +595,7 @@
     </message>
     <message>
         <source>You&apos;re watching &quot;%1&quot;</source>
-        <translation>Você está assistindo &quot;%1&quot;</translation>
+        <translation type="obsolete">Você está assistindo &quot;%1&quot;</translation>
     </message>
     <message>
         <source>You can now paste the YouTube link into another application</source>
@@ -607,23 +611,23 @@
     </message>
     <message>
         <source>This is just the demo version of %1.</source>
-        <translation type="unfinished"></translation>
+        <translation>Esta é apenas a versão demonstação de %1.</translation>
     </message>
     <message>
         <source>It allows you to test the application and see if it works for you.</source>
-        <translation type="unfinished"></translation>
+        <translation>Ele permite que você teste o aplicativo e veja se ele funciona para você.</translation>
     </message>
     <message>
         <source>Continue</source>
-        <translation type="unfinished"></translation>
+        <translation>Continuar</translation>
     </message>
     <message>
         <source>Get the full version</source>
-        <translation type="unfinished"></translation>
+        <translation>Obter a versão completa</translation>
     </message>
     <message>
         <source>Downloading %1</source>
-        <translation type="unfinished"></translation>
+        <translation>Baixando %1</translation>
     </message>
 </context>
 <context>
@@ -639,41 +643,41 @@
         <source>%1 views</source>
         <translation>%1 exibições</translation>
     </message>
-    <message>
-        <source>%1 of %2 (%3) ? %4</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <source>Preparing</source>
-        <translation type="unfinished"></translation>
+        <translation>Preparando</translation>
     </message>
     <message>
         <source>Failed</source>
-        <translation type="unfinished"></translation>
+        <translation>Falhou</translation>
     </message>
     <message>
         <source>Completed</source>
-        <translation type="unfinished"></translation>
+        <translation>Finalizado</translation>
     </message>
     <message>
         <source>Stopped</source>
-        <translation type="unfinished"></translation>
+        <translation>Parado</translation>
     </message>
     <message>
         <source>Stop downloading</source>
-        <translation type="unfinished"></translation>
+        <translation>Parar download</translation>
     </message>
     <message>
         <source>Show in %1</source>
-        <translation type="unfinished"></translation>
+        <translation>Mostrar em %1</translation>
     </message>
     <message>
         <source>Open parent folder</source>
-        <translation type="unfinished"></translation>
+        <translation>Abrir pasta pai</translation>
     </message>
     <message>
         <source>Restart downloading</source>
-        <translation type="unfinished"></translation>
+        <translation>Reiniciar download</translation>
+    </message>
+    <message>
+        <source>%1 of %2 (%3) — %4</source>
+        <translation>%1 de %2 (%3) — %4</translation>
     </message>
 </context>
 <context>
@@ -691,7 +695,7 @@
     </message>
     <message>
         <source>Enter a keyword to start watching videos.</source>
-        <translation>Digite uma palavra-chave para começar a assistir os vídeos.</translation>
+        <translation type="obsolete">Digite uma palavra-chave para começar a assistir vídeos.</translation>
     </message>
     <message>
         <source>Watch</source>
@@ -709,6 +713,31 @@
         <source>Make yourself comfortable</source>
         <translation>Sinta-se confortável</translation>
     </message>
+    <message>
+        <source>Get the full version</source>
+        <translation>Obter a versão completa</translation>
+    </message>
+    <message>
+        <source>Enter</source>
+        <extracomment>&quot;Enter&quot;, as in &quot;type&quot;. The whole frase says: &quot;Enter a keyword to start watching videos&quot;</extracomment>
+        <translation>Digite</translation>
+    </message>
+    <message>
+        <source>a keyword</source>
+        <translation>uma palavra chave</translation>
+    </message>
+    <message>
+        <source>a channel</source>
+        <translation>um canal</translation>
+    </message>
+    <message>
+        <source>to start watching videos.</source>
+        <translation>para começar a assistir vídeos.</translation>
+    </message>
+    <message>
+        <source>Recent channels</source>
+        <translation>Canais recentes</translation>
+    </message>
 </context>
 <context>
     <name>SettingsView</name>
@@ -730,7 +759,7 @@
     </message>
     <message>
         <source>&amp;Clear recent keywords</source>
-        <translation type="obsolete">Palavras-chave &amp;limpas recentemente</translation>
+        <translation type="obsolete">&amp;Limpar palavras-chave recentes</translation>
     </message>
     <message>
         <source>&amp;Close</source>
@@ -743,5 +772,9 @@
         <source>Network error: %1 for %2</source>
         <translation>Erro na rede: %1 para %2</translation>
     </message>
+    <message>
+        <source>Cannot get video stream for %1</source>
+        <translation>Não foi possível obter stream de vídeo de %1</translation>
+    </message>
 </context>
 </TS>
