@@ -331,7 +331,7 @@
     </message>
     <message>
         <source>&amp;Clear recent keywords</source>
-        <translation>&amp;Limpar pesquisas recentes</translation>
+        <translation type="obsolete">&amp;Limpar pesquisas recentes</translation>
     </message>
     <message>
         <source>Clear the search history. Cannot be undone.</source>
@@ -489,6 +489,10 @@
         <source>Downloads complete</source>
         <translation>Transferência completa</translation>
     </message>
+    <message>
+        <source>&amp;Clear recent searches</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>MediaView</name>
@@ -518,7 +522,7 @@
     </message>
     <message>
         <source>You&apos;re watching &quot;%1&quot;</source>
-        <translation>Está a assistir a &quot;%1&quot;</translation>
+        <translation type="obsolete">Está a assistir a &quot;%1&quot;</translation>
     </message>
     <message>
         <source>This is just the demo version of %1.</source>
@@ -556,7 +560,7 @@
     </message>
     <message>
         <source>%1 of %2 (%3) ? %4</source>
-        <translation>%1 de %2 (%3) ? %4</translation>
+        <translation type="obsolete">%1 de %2 (%3) ? %4</translation>
     </message>
     <message>
         <source>Preparing</source>
@@ -590,6 +594,10 @@
         <source>Restart downloading</source>
         <translation>Recomeçar a transferência</translation>
     </message>
+    <message>
+        <source>%1 of %2 (%3) — %4</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>SearchLineEdit</name>
@@ -606,7 +614,7 @@
     </message>
     <message>
         <source>Enter a keyword to start watching videos.</source>
-        <translation>Insira uma pesquisa para começar a assitir a vídeos.</translation>
+        <translation type="obsolete">Insira uma pesquisa para começar a assitir a vídeos.</translation>
     </message>
     <message>
         <source>Watch</source>
@@ -624,6 +632,31 @@
         <source>Make yourself comfortable</source>
         <translation>Acomode-se confortavelmente</translation>
     </message>
+    <message>
+        <source>Get the full version</source>
+        <translation type="unfinished">Transfira a versão completa</translation>
+    </message>
+    <message>
+        <source>Enter</source>
+        <extracomment>&quot;Enter&quot;, as in &quot;type&quot;. The whole frase says: &quot;Enter a keyword to start watching videos&quot;</extracomment>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>a keyword</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>a channel</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>to start watching videos.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Recent channels</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>Video</name>
@@ -631,5 +664,9 @@
         <source>Network error: %1 for %2</source>
         <translation>Erro de rede: %1 para %2</translation>
     </message>
+    <message>
+        <source>Cannot get video stream for %1</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 </TS>
