@@ -453,7 +453,7 @@
     </message>
     <message>
         <source>&amp;Clear recent keywords</source>
-        <translation>Şterge &amp;căutările recente</translation>
+        <translation type="obsolete">Şterge &amp;căutările recente</translation>
     </message>
     <message>
         <source>&amp;Application</source>
@@ -535,6 +535,10 @@
         <source>Downloads complete</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>&amp;Clear recent searches</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>MediaView</name>
@@ -552,7 +556,7 @@
     </message>
     <message>
         <source>You&apos;re watching &quot;%1&quot;</source>
-        <translation>Te uiţi la %1</translation>
+        <translation type="obsolete">Te uiţi la %1</translation>
     </message>
     <message>
         <source>You can now paste the YouTube link into another application</source>
@@ -600,10 +604,6 @@
         <source>%1 views</source>
         <translation>%1 vizualizări</translation>
     </message>
-    <message>
-        <source>%1 of %2 (%3) ? %4</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <source>Preparing</source>
         <translation type="unfinished"></translation>
@@ -636,6 +636,10 @@
         <source>Restart downloading</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>%1 of %2 (%3) — %4</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>SearchLineEdit</name>
@@ -652,7 +656,7 @@
     </message>
     <message>
         <source>Enter a keyword to start watching videos.</source>
-        <translation>Efectuaţi o căutare pentru a începe să vizionaţi videoclipuri.</translation>
+        <translation type="obsolete">Efectuaţi o căutare pentru a începe să vizionaţi videoclipuri.</translation>
     </message>
     <message>
         <source>Watch</source>
@@ -670,6 +674,31 @@
         <source>Make yourself comfortable</source>
         <translation>Faceţi-vă confortabil</translation>
     </message>
+    <message>
+        <source>Get the full version</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Enter</source>
+        <extracomment>&quot;Enter&quot;, as in &quot;type&quot;. The whole frase says: &quot;Enter a keyword to start watching videos&quot;</extracomment>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>a keyword</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>a channel</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>to start watching videos.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Recent channels</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>SettingsView</name>
@@ -684,5 +713,9 @@
         <source>Network error: %1 for %2</source>
         <translation>Eroare reţea: %1 pentru %2</translation>
     </message>
+    <message>
+        <source>Cannot get video stream for %1</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 </TS>
