@@ -497,7 +497,7 @@
     </message>
     <message>
         <source>&amp;Clear recent keywords</source>
-        <translation>&amp;Очистить последние запросы</translation>
+        <translation type="obsolete">&amp;Очистить последние запросы</translation>
     </message>
     <message>
         <source>Clear the search history. Cannot be undone.</source>
@@ -575,6 +575,10 @@
         <source>Downloads complete</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>&amp;Clear recent searches</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>MediaView</name>
@@ -592,7 +596,7 @@
     </message>
     <message>
         <source>You&apos;re watching &quot;%1&quot;</source>
-        <translation>Сейчас просматривается &quot;%1&quot;</translation>
+        <translation type="obsolete">Сейчас просматривается &quot;%1&quot;</translation>
     </message>
     <message>
         <source>You can now paste the YouTube link into another application</source>
@@ -640,10 +644,6 @@
         <source>%1 views</source>
         <translation>%1 просмотров</translation>
     </message>
-    <message>
-        <source>%1 of %2 (%3) ? %4</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <source>Preparing</source>
         <translation type="unfinished"></translation>
@@ -676,6 +676,10 @@
         <source>Restart downloading</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>%1 of %2 (%3) — %4</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>SearchLineEdit</name>
@@ -692,7 +696,7 @@
     </message>
     <message>
         <source>Enter a keyword to start watching videos.</source>
-        <translation>Введите ключевые слова для начала просмотра видео.</translation>
+        <translation type="obsolete">Введите ключевые слова для начала просмотра видео.</translation>
     </message>
     <message>
         <source>Watch</source>
@@ -710,6 +714,31 @@
         <source>Make yourself comfortable</source>
         <translation>Чувствуйте себя как дома</translation>
     </message>
+    <message>
+        <source>Get the full version</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Enter</source>
+        <extracomment>&quot;Enter&quot;, as in &quot;type&quot;. The whole frase says: &quot;Enter a keyword to start watching videos&quot;</extracomment>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>a keyword</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>a channel</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>to start watching videos.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Recent channels</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>SettingsView</name>
@@ -744,5 +773,9 @@
         <source>Network error: %1 for %2</source>
         <translation>Ошибка сети: %1 на %2</translation>
     </message>
+    <message>
+        <source>Cannot get video stream for %1</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 </TS>
