@@ -497,7 +497,7 @@
     </message>
     <message>
         <source>&amp;Clear recent keywords</source>
-        <translation>Очистити недавн&amp;ій пошук</translation>
+        <translation type="obsolete">Очистити недавн&amp;ій пошук</translation>
     </message>
     <message>
         <source>Clear the search history. Cannot be undone.</source>
@@ -575,6 +575,10 @@
         <source>Downloads complete</source>
         <translation>Завантаження завершено</translation>
     </message>
+    <message>
+        <source>&amp;Clear recent searches</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>MediaView</name>
@@ -592,7 +596,7 @@
     </message>
     <message>
         <source>You&apos;re watching &quot;%1&quot;</source>
-        <translation>Ви дивитесь &quot;%1&quot;</translation>
+        <translation type="obsolete">Ви дивитесь &quot;%1&quot;</translation>
     </message>
     <message>
         <source>You can now paste the YouTube link into another application</source>
@@ -642,7 +646,7 @@
     </message>
     <message>
         <source>%1 of %2 (%3) ? %4</source>
-        <translation>%1 з %2 (%3) ? %4</translation>
+        <translation type="obsolete">%1 з %2 (%3) ? %4</translation>
     </message>
     <message>
         <source>Preparing</source>
@@ -676,6 +680,10 @@
         <source>Restart downloading</source>
         <translation>Завантажити заново</translation>
     </message>
+    <message>
+        <source>%1 of %2 (%3) — %4</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>SearchLineEdit</name>
@@ -692,7 +700,7 @@
     </message>
     <message>
         <source>Enter a keyword to start watching videos.</source>
-        <translation>Введіть фрази для пошуку відео.</translation>
+        <translation type="obsolete">Введіть фрази для пошуку відео.</translation>
     </message>
     <message>
         <source>Watch</source>
@@ -710,6 +718,31 @@
         <source>Make yourself comfortable</source>
         <translation>Влаштовуйтеся якнайзручніше</translation>
     </message>
+    <message>
+        <source>Get the full version</source>
+        <translation type="unfinished">Отримати повнофункціональну версію</translation>
+    </message>
+    <message>
+        <source>Enter</source>
+        <extracomment>&quot;Enter&quot;, as in &quot;type&quot;. The whole frase says: &quot;Enter a keyword to start watching videos&quot;</extracomment>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>a keyword</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>a channel</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>to start watching videos.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Recent channels</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>SettingsView</name>
@@ -744,5 +777,9 @@
         <source>Network error: %1 for %2</source>
         <translation>Помилка мережі: %1 для %2</translation>
     </message>
+    <message>
+        <source>Cannot get video stream for %1</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 </TS>
