@@ -124,7 +124,7 @@ MediaView::MediaView(QWidget *parent) : QWidget(parent) {
 #ifdef APP_DEMO
     demoTimer = new QTimer(this);
     demoTimer->setSingleShot(true);
-    demoTimer->setInterval(60000);
+    demoTimer->setInterval(30000);
     connect(demoTimer, SIGNAL(timeout()), SLOT(demoMessage()));
 #endif
 
@@ -140,12 +140,12 @@ void MediaView::initialize() {
 void MediaView::setMediaObject(Phonon::MediaObject *mediaObject) {
     this->mediaObject = mediaObject;
     Phonon::createPath(this->mediaObject, videoWidget);
-    connect(mediaObject, SIGNAL(finished()), this, SLOT(skip()));
+    connect(mediaObject, SIGNAL(finished()), this, SLOT(playbackFinished()));
     connect(mediaObject, SIGNAL(stateChanged(Phonon::State, Phonon::State)),
             this, SLOT(stateChanged(Phonon::State, Phonon::State)));
     connect(mediaObject, SIGNAL(currentSourceChanged(Phonon::MediaSource)),
             this, SLOT(currentSourceChanged(Phonon::MediaSource)));
-    connect(mediaObject, SIGNAL(bufferStatus(int)), loadingWidget, SLOT(bufferStatus(int)));
+    // connect(mediaObject, SIGNAL(bufferStatus(int)), loadingWidget, SLOT(bufferStatus(int)));
 }
 
 void MediaView::search(SearchParams *searchParams) {
@@ -183,7 +183,10 @@ void MediaView::search(SearchParams *searchParams) {
         if (separator > 0 && separator + 1 < keyword.length()) {
             display = keyword.mid(separator+1);
         }
-    }
+
+        // also hide sidebar
+        playlistWidget->hide();
+    } else playlistWidget->show();
     // tr("You're watching \"%1\"").arg(searchParams->keywords())
 
 }
@@ -214,35 +217,35 @@ void MediaView::stateChanged(Phonon::State newState, Phonon::State /*oldState*/)
         break;
 
     case Phonon::PlayingState:
-        //qDebug("playing");
+        // qDebug("playing");
         videoAreaWidget->showVideo();
         break;
 
     case Phonon::StoppedState:
-        //qDebug("stopped");
+        // qDebug("stopped");
         // play() has already been called when setting the source
         // but Phonon on Linux needs a little more help to start playback
-        if (!reallyStopped) mediaObject->play();
+        // if (!reallyStopped) mediaObject->play();
 
 #ifdef APP_MAC
         // Workaround for Mac playback start problem
         if (!timerPlayFlag) {
-            workaroundTimer->start();
+            // workaroundTimer->start();
         }
 #endif
 
         break;
 
          case Phonon::PausedState:
-        //qDebug("paused");
+        qDebug("paused");
         break;
 
          case Phonon::BufferingState:
-        //qDebug("buffering");
+        qDebug("buffering");
         break;
 
          case Phonon::LoadingState:
-        //qDebug("loading");
+        qDebug("loading");
         break;
 
          default:
@@ -271,6 +274,7 @@ void MediaView::stop() {
     errorTimer->stop();
     listView->selectionModel()->clearSelection();
     if (downloadItem) {
+        downloadItem->stop();
         delete downloadItem;
         downloadItem = 0;
     }
@@ -289,6 +293,7 @@ void MediaView::activeRowChanged(int row) {
 
     mediaObject->pause();
     if (downloadItem) {
+        downloadItem->stop();
         delete downloadItem;
         downloadItem = 0;
     }
@@ -326,18 +331,29 @@ void MediaView::gotStreamUrl(QUrl streamUrl) {
     }
     video->disconnect(this);
 
+
     QString tempDir = QDesktopServices::storageLocation(QDesktopServices::TempLocation);
+#ifdef Q_WS_X11
+    QString tempFile = tempDir + "/minitube-" + getenv("USERNAME") + ".mp4";
+#else
     QString tempFile = tempDir + "/minitube.mp4";
-    if (!QFile::remove(tempFile)) {
+#endif
+    if (QFile::exists(tempFile) && !QFile::remove(tempFile)) {
         qDebug() << "Cannot remove temp file";
     }
 
     Video *videoCopy = video->clone();
-    if (downloadItem) delete downloadItem;
+    if (downloadItem) {
+        downloadItem->stop();
+        delete downloadItem;
+    }
     downloadItem = new DownloadItem(videoCopy, streamUrl, tempFile, this);
     connect(downloadItem, SIGNAL(statusChanged()), SLOT(downloadStatusChanged()));
     // connect(downloadItem, SIGNAL(progress(int)), SLOT(downloadProgress(int)));
+    connect(downloadItem, SIGNAL(bufferProgress(int)), loadingWidget, SLOT(bufferStatus(int)));
     // connect(downloadItem, SIGNAL(finished()), SLOT(itemFinished()));
+    connect(video, SIGNAL(errorStreamUrl(QString)), SLOT(handleError(QString)));
+    connect(downloadItem, SIGNAL(error(QString)), SLOT(handleError(QString)));
     downloadItem->start();
 
 }
@@ -376,15 +392,16 @@ void MediaView::downloadStatusChanged() {
         startPlaying();
         break;
     case Starting:
-        qDebug() << "Starting";
+        // qDebug() << "Starting";
         break;
     case Finished:
-        qDebug() << "Finished";
+        // qDebug() << "Finished" << mediaObject->state();
+        // if (mediaObject->state() == Phonon::StoppedState) startPlaying();
         break;
     case Failed:
-        qDebug() << "Failed";
+        // qDebug() << "Failed";
     case Idle:
-        qDebug() << "Idle";
+        // qDebug() << "Idle";
         break;
     }
 }
@@ -446,6 +463,18 @@ void MediaView::skip() {
     listModel->setActiveRow(nextRow);
 }
 
+void MediaView::playbackFinished() {
+    if (mediaObject->currentTime() < mediaObject->totalTime()) {
+        // mediaObject->seek(mediaObject->currentTime());
+        QTimer::singleShot(3000, this, SLOT(playbackResume()));
+    } else skip();
+}
+
+void MediaView::playbackResume() {
+    mediaObject->seek(mediaObject->currentTime());
+    mediaObject->play();
+}
+
 void MediaView::openWebPage() {
     Video* video = listModel->activeVideo();
     if (!video) return;
@@ -578,6 +607,7 @@ void MediaView::demoMessage() {
         QDesktopServices::openUrl(QString(Constants::WEBSITE) + "#download");
     } else {
         mediaObject->play();
+        demoTimer->start();
     }
 }
 #endif
