@@ -2,9 +2,13 @@
 #include <qtsingleapplication.h>
 #include "constants.h"
 #include "MainWindow.h"
+#include "searchparams.h"
 #ifdef APP_MAC
 // #include "local/mac/mac_startup.h"
 #endif
+#ifdef APP_WIN
+#include "local/win/qtwin.h"
+#endif
 
 int main(int argc, char **argv) {
 
@@ -66,6 +70,14 @@ int main(int argc, char **argv) {
     mainWin.setWindowIcon(appIcon);
 #endif
 
+#ifdef APP_WIN
+    if (QtWin::isCompositionEnabled()) {
+        QtWin::extendFrameIntoClientArea(&mainWin);
+        mainWin.setContentsMargins(0, 0, 0, 0);
+    }
+    app.setFont(QFont("Segoe UI", 9));
+#endif
+
     mainWin.show();
 
     app.setActivationWindow(&mainWin, true);
@@ -73,5 +85,12 @@ int main(int argc, char **argv) {
     // all string literals are UTF-8
     QTextCodec::setCodecForCStrings(QTextCodec::codecForName("UTF-8"));
 
+    if (app.arguments().size() > 1) {
+        QString query = app.arguments().at(1);
+        SearchParams *searchParams = new SearchParams();
+        searchParams->setKeywords(query);
+        mainWin.showMedia(searchParams);
+    }
+
     return app.exec();
 }
